# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='HNDataStock',
    version='0.1.2',
    author='Hướng Nghiệp Dữ Liệu',
    author_email='daotao@huongnghiepdulieu.com',
    description='Trường đào tạo lập trình Forex, Crypto, Chứng Khoán',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='http://www.huongnghiepdulieu.com',
    packages=find_packages(),
    install_requires=[
        
    ],
    classifiers=[
        
    ],
)
